@@ -1,20 +1,16 @@
-pub mod setup;
-
-use std::{
-	fs::{self, read_to_string},
-	path::PathBuf,
-};
-
+use crate::paths::binst_bin_dir;
+use crate::repo::error::BinRepoError;
+use crate::repo::{BinRepo, MAIN_STREAM};
+use crate::utils::{clean_path, get_toml_value_as_string, UtilsError};
 use clap::ArgMatches;
 use semver::Version;
+use std::fs::{self, read_to_string};
+use std::path::PathBuf;
 use thiserror::Error;
 use toml::Value;
 
-use crate::{
-	paths::binst_bin_dir,
-	repo::{extract_opts_from_argc, BinRepo, BinRepoError, MAIN_STREAM},
-	utils::{clean_path, get_toml_value_as_string, UtilsError},
-};
+pub mod argc;
+pub mod setup;
 
 struct InstalledBinInfo {
 	stream: String,
@@ -24,57 +20,23 @@ struct InstalledBinInfo {
 
 pub const CARGO_TOML: &str = "Cargo.toml";
 
-#[derive(Error, Debug)]
-pub enum ExecError {
-	#[error("Must have a -r repo_url for now (later can be found from later)")]
-	NoRepo,
-
-	#[error("Install command must have a binary name in argument")]
-	NoBinName,
-
-	#[error("No repo in argument or in install.toml {0}")]
-	NoRepoFoundInArgumentOrInInstallToml(String),
-
-	#[error("Cannot find package dir for bin {0}")]
-	CannotFindBinPackageDir(String),
-
-	#[error("Version could not be found from bin path {0}")]
-	NoVersionFromBinPath(String),
-
-	#[error(transparent)]
-	BinRepoError(#[from] BinRepoError),
-
-	#[error(transparent)]
-	IOError(#[from] std::io::Error),
-
-	#[error(transparent)]
-	TomlError(#[from] toml::de::Error),
-
-	#[error(transparent)]
-	SemVerError(#[from] semver::Error),
-
-	#[error(transparent)]
-	UtilsError(#[from] UtilsError),
-}
-
 #[tokio::main]
 pub async fn exec_install(argc: &ArgMatches) -> Result<(), ExecError> {
 	let bin_name = argc.value_of("bin_name").ok_or(ExecError::NoBinName)?;
-	let repo_path = argc.value_of("repo").ok_or(ExecError::NoRepo)?;
-	let bin_repo = BinRepo::new(bin_name, repo_path, extract_opts_from_argc(argc))?;
+	let bin_repo = BinRepo::new(bin_name, argc, false)?;
 
 	let stream = argc.value_of("stream").unwrap_or(MAIN_STREAM).to_owned();
-	Ok(bin_repo.install(stream).await?)
+	bin_repo.install(stream).await?;
+	Ok(())
 }
 
 #[tokio::main]
 pub async fn exec_publish(argc: &ArgMatches) -> Result<(), ExecError> {
-	let repo_path = argc.value_of("repo").ok_or(ExecError::NoRepo)?;
 	let toml = read_to_string(CARGO_TOML)?;
 	let toml: Value = toml::from_str(&toml)?;
 	let bin_name = get_toml_value_as_string(&toml, &["package", "name"])?;
 
-	let bin_repo = BinRepo::new(&bin_name, repo_path, extract_opts_from_argc(argc))?;
+	let bin_repo = BinRepo::new(&bin_name, argc, true)?;
 	let at_path = argc.value_of("path").map(clean_path);
 
 	Ok(bin_repo.publish(at_path).await?)
@@ -90,7 +52,7 @@ pub async fn exec_update(argc: &ArgMatches) -> Result<(), ExecError> {
 		version: installed_version,
 	} = extract_installed_bin_info(bin_name)?;
 
-	let repo = BinRepo::new(&bin_name, &repo_raw, extract_opts_from_argc(argc))?;
+	let repo = BinRepo::new(&bin_name, argc, false)?;
 	let origin_toml = repo.get_origin_latest_toml_content(&stream).await?;
 
 	let origin_toml: Value = toml::from_str(&origin_toml)?;
@@ -100,7 +62,10 @@ pub async fn exec_update(argc: &ArgMatches) -> Result<(), ExecError> {
 	println!("Updating {} from repo {}", &bin_name, &repo_raw);
 
 	if origin_version > installed_version {
-		println!("  Installing emote version {} ( > local version {})", origin_version, installed_version);
+		println!(
+			"  Installing emote version {} ( > local version {})",
+			origin_version, installed_version
+		);
 		repo.install(stream).await?;
 	} else {
 		println!(
@@ -138,7 +103,11 @@ fn extract_installed_bin_info(bin_name: &str) -> Result<InstalledBinInfo, ExecEr
 	// get the repo
 	let repo_raw = match get_toml_value_as_string(&install_toml, &["install", "repo"]) {
 		Ok(repo) => repo,
-		Err(_) => return Err(ExecError::NoRepoFoundInArgumentOrInInstallToml(install_toml_path.to_string_lossy().to_string())),
+		Err(_) => {
+			return Err(ExecError::NoRepoFoundInArgumentOrInInstallToml(
+				install_toml_path.to_string_lossy().to_string(),
+			))
+		}
 	};
 
 	Ok(InstalledBinInfo { version, stream, repo_raw })
@@ -155,3 +124,33 @@ fn get_version_dir_from_symlink(bin_name: &str) -> Result<PathBuf, ExecError> {
 		None => Err(ExecError::CannotFindBinPackageDir(bin_symlink.to_string_lossy().to_string())),
 	}
 }
+
+#[derive(Error, Debug)]
+pub enum ExecError {
+	#[error("Install command must have a binary name in argument")]
+	NoBinName,
+
+	#[error("No repo in argument or in install.toml {0}")]
+	NoRepoFoundInArgumentOrInInstallToml(String),
+
+	#[error("Cannot find package dir for bin {0}")]
+	CannotFindBinPackageDir(String),
+
+	#[error("Version could not be found from bin path {0}")]
+	NoVersionFromBinPath(String),
+
+	#[error(transparent)]
+	BinRepoError(#[from] BinRepoError),
+
+	#[error(transparent)]
+	IOError(#[from] std::io::Error),
+
+	#[error(transparent)]
+	TomlError(#[from] toml::de::Error),
+
+	#[error(transparent)]
+	SemVerError(#[from] semver::Error),
+
+	#[error(transparent)]
+	UtilsError(#[from] UtilsError),
+}
